@@ -123,32 +123,31 @@ class PostgresLock(locking.Lock):
             if not self._conn or self._conn.closed:
                 self._conn = PostgresDriver.get_connection(self._parsed_url,
                                                            self._options)
-            try:
-                with _translating_cursor(self._conn) as cur:
-                    if blocking is True:
-                        cur.execute("SELECT pg_advisory_lock(%s, %s);",
-                                    self.key)
-                        cur.fetchone()
+
+            with _translating_cursor(self._conn) as cur:
+                if blocking is True:
+                    cur.execute("SELECT pg_advisory_lock(%s, %s);",
+                                self.key)
+                    cur.fetchone()
+                    self.acquired = True
+                    return True
+                else:
+                    cur.execute("SELECT pg_try_advisory_lock(%s, %s);",
+                                self.key)
+                    if cur.fetchone()[0] is True:
                         self.acquired = True
                         return True
+                    elif blocking is False:
+                        self._conn.close()
+                        return False
                     else:
-                        cur.execute("SELECT pg_try_advisory_lock(%s, %s);",
-                                    self.key)
-                        if cur.fetchone()[0] is True:
-                            self.acquired = True
-                            return True
-                        elif blocking is False:
-                            self._conn.close()
-                            return False
-                        else:
-                            raise _retry.TryAgain
-            except _retry.TryAgain:
-                pass  # contine to retrieve lock on same conn
-            except Exception:
-                self._conn.close()
-                raise
+                        raise _retry.TryAgain
 
-        return _lock()
+        try:
+            return _lock()
+        except Exception:
+            self._conn.close()
+            raise
 
     def release(self):
         if not self.acquired:
